.. module:: enaml.widgets.multiline_field

=============================
enaml.widgets.multiline_field
=============================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    MultilineField


.. autoclass:: MultilineField
